@@ -5,16 +5,20 @@ require_relative '../strings'
 module Strings
   module Extensions
     refine String do
-      def align(*args)
-        Align.align(self, *args)
+      def align(*args, **kws)
+        Align.align(self, *args, **kws)
       end
 
-      def align_left(*args)
-        Align.align_left(self, *args)
+      def align_left(*args, **kws)
+        Align.align_left(self, *args, **kws)
       end
 
-      def align_right(*args)
-        Align.align_right(self, *args)
+      def align_center(*args, **kws)
+        Align.align_center(self, *args, **kws)
+      end
+
+      def align_right(*args, **kws)
+        Align.align_right(self, *args, **kws)
       end
 
       def ansi?
@@ -25,8 +29,8 @@ module Strings
         Fold.fold(self, *args)
       end
 
-      def pad(*args)
-        Pad.pad(self, *args)
+      def pad(*args, **kws)
+        Pad.pad(self, *args, **kws)
       end
 
       def sanitize
@@ -37,8 +41,8 @@ module Strings
         Truncate.truncate(self, *args)
       end
 
-      def wrap(*args)
-        Wrap.wrap(self, *args)
+      def wrap(*args, **kws)
+        Wrap.wrap(self, *args, **kws)
       end
     end
   end # Extensions
